Learn R Programming

RWinEdt (version 1.8-3)

RWinEdt - Internals: Internal functions of the package RWinEdt

Description

These internal functions are not intended to be called by the user. Instead, a simple click into the menu is sufficient.

Usage

getWinEdt()
installWinEdt(InstallRoot, ApplData, force = FALSE)
startWinEdt(InstallRoot, ApplData)

Arguments

InstallRoot
The path where WinEdt is installed.
ApplData
The path to the user's Application Data directory of WinEdt.
force
If FALSE (default), no files of an already installed version of R-WinEdt are overwritten; if TRUE those files will be overwritten; if NULL, the user will be asked.

References

Ligges, U. (2003): R-WinEdt. In: Hornik, K., Leisch, F. and Zeileis, A. (eds.), Proceedings of the 3rd International Workshop on Distributed Statistical Computing (DSC 2003), March 20-22, TU Wien, Vienna, Austria. ISSN 1609-395X, http://www.ci.tuwien.ac.at/Conferences/DSC-2003/Proceedings/.